﻿using System;
using System.Collections.Generic;
//using System.Linq;
using System.Text;
using Ivi.Visa.Interop;
//'' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
//''  © Agilent Technologies, Inc. 2013
//''
//'' You have a royalty-free right to use, modify, reproduce and distribute
//'' the Sample Application Files (and/or any modified version) in any way
//'' you find useful, provided that you agree that Agilent Technologies has no
//'' warranty,  obligations or liability for any Sample Application Files.
//''
//'' Agilent Technologies provides programming examples for illustration only,
//'' This sample program assumes that you are familiar with the programming
//'' language being demonstrated and the tools used to create and debug
//'' procedures. Agilent Technologies support engineers can help explain the
//'' functionality of Agilent Technologies software components and associated
//'' commands, but they will not modify these samples to provide added
//'' functionality or construct procedures to meet your specific needs.
//'' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

namespace ExtTriggering
{
    class ExtTrig
    {
        static void Main(string[] args)
        {
            ExtTrig DmmClass = new ExtTrig(); //Create an instance of this class so we can call functions from Main

             //This example sets the DMM up in the Ext trig mode. This mode waits for a signal to come in on the Ext Trig connector then starts a measurement.
             //It will setup a trigger count of 5 triggers. This means that one the DMM is in the wait for trigger state, it will accept 5 trigger signals before returning
             //to the idle trigger state. 

            // This example requires an external signal connected to the "Ext Trig in" connector. The signal should provide a TTL positive going signal to the DMM.
            // If the signal is not provided the program will encounter an exception with an error message "Unexpected I/O data termination"

            //For more information on getting started using VISA COM I/O operations see the app note located at:
            //http://cp.literature.agilent.com/litweb/pdf/5989-6338EN.pdf

            Ivi.Visa.Interop.ResourceManager rm = new Ivi.Visa.Interop.ResourceManager(); //Open up a new resource manager
            Ivi.Visa.Interop.FormattedIO488 myDmm = new Ivi.Visa.Interop.FormattedIO488(); //Open a new Formatted IO 488 session 
            try
            {
                //string DutAddr = "GPIB0::22"; //String for GPIB
                //string DutAddr = ""TCPIP0::169.254.4.61";  //Example string for LAN
                //string DutAddr = "USB0::0x0957::0x1A07::MY53000101"; //Example string for USB
                string DutAddr = "USB0::0x0957::0x1C07::US00000069::0::INSTR"; //String for GPIB

                myDmm.IO = (IMessage)rm.Open(DutAddr, AccessMode.NO_LOCK, 5000, ""); //Open up a handle to the DMM with a 5 second timeout


                //First start with a reset state
                myDmm.IO.Clear(); //Send a device clear first to stop any measurements in process
                myDmm.WriteString("*RST", true); //Reset the device
                myDmm.WriteString("*IDN?", true); //Get the IDN string                
                string IDN = myDmm.ReadString();
                Console.WriteLine(IDN); //report the DMM's identity

                
                
                //Configure for DCV 100V range, 10mV resolution this is a fast reading
                myDmm.WriteString("CONF:VOLT:DC", true);

                //Configure the Trigger Count
                myDmm.WriteString("TRIG:COUN 5", true); //Set the trigger count to 5. 

                //Configure the Trigger source
                myDmm.WriteString("TRIG:SOUR EXT", true);
                //Configure the Ext Trigger to look for a positive slope signal.
                myDmm.WriteString("TRIG:SLOP POS", true);

                //Setup the Voltmeter complete connector to output a positive signal. This connector always puts out a signal when the measurement is complete.
                // This command only determines the polarity of the signal. It does not turn the signal on or off.
                myDmm.WriteString("OUTP:TRIG:SLOP POS", true);

                myDmm.WriteString("READ?", true); //Set the DMM to wait for trigger state and get readings after ext trigger signal.
                Object[] DCVResult = (object[])myDmm.ReadList(IEEEASCIIType.ASCIIType_Any, ",;"); //Get the readings in an array                
                foreach (double rdg in DCVResult) //Write out each result to the console
                    Console.WriteLine(rdg.ToString());



            }
            catch (Exception e)
            {
                Console.WriteLine("Error occured: " + e.Message);
            }
            finally
            {
                //Close out your resources
                try { myDmm.IO.Close(); }
                catch { }
                try { System.Runtime.InteropServices.Marshal.ReleaseComObject(myDmm); }
                catch { }
                try
                {
                    System.Runtime.InteropServices.Marshal.ReleaseComObject(rm);
                }
                catch { }
                Console.WriteLine("Press any key to continue...");
                Console.ReadKey();

            }
        }
    }
}
